@@ -59,6 +59,7 @@ def test_create_user(mock_session, client):
         last_name="Doe",
         roles=["role1", "role2"],
         custom_claims={"company": "Test Corp"},
+        mark_as_verified=True,
     )
 
     # Verify request was made correctly
@@ -71,6 +72,7 @@ def test_create_user(mock_session, client):
             "last_name": "Doe",
             "roles": ["role1", "role2"],
             "custom_claims": {"company": "Test Corp"},
+            "mark_as_verified": True,
         },
         params=None,
     )
